Class: Aws::SSMQuickSetup::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMQuickSetup::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmquicksetup/client.rb,
sig/client.rbs
Overview
An API client for SSMQuickSetup. To construct a client, you need to configure a :region and :credentials.
client = Aws::SSMQuickSetup::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConfigurationManagerResponseSuccess, _GetConfigurationManagerResponseSuccess, _GetConfigurationResponseSuccess, _GetServiceSettingsResponseSuccess, _ListConfigurationManagersResponseSuccess, _ListConfigurationsResponseSuccess, _ListQuickSetupTypesResponseSuccess, _ListTagsForResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource.
-
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
-
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
-
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
-
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
-
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1054 1055 1056 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1054 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1057 1058 1059 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1057 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1027 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMQuickSetup') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmquicksetup' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource. This object is a collection of desired state configurations for multiple configuration definitions and summaries describing the deployments of those definitions.
86 |
# File 'sig/client.rbs', line 86
def create_configuration_manager: (
|
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
103 |
# File 'sig/client.rbs', line 103
def delete_configuration_manager: (
|
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
123 |
# File 'sig/client.rbs', line 123
def get_configuration: (
|
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
140 |
# File 'sig/client.rbs', line 140
def get_configuration_manager: (
|
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
150 151 |
# File 'sig/client.rbs', line 150
def get_service_settings: () -> _GetServiceSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetServiceSettingsResponseSuccess
|
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
159 |
# File 'sig/client.rbs', line 159
def list_configuration_managers: (
|
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
177 |
# File 'sig/client.rbs', line 177
def list_configurations: (
|
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
196 197 |
# File 'sig/client.rbs', line 196
def list_quick_setup_types: () -> _ListQuickSetupTypesResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _ListQuickSetupTypesResponseSuccess
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
204 |
# File 'sig/client.rbs', line 204
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
210 |
# File 'sig/client.rbs', line 210
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
217 |
# File 'sig/client.rbs', line 217
def untag_resource: (
|
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
224 |
# File 'sig/client.rbs', line 224
def update_configuration_definition: (
|
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
235 |
# File 'sig/client.rbs', line 235
def update_configuration_manager: (
|
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
243 |
# File 'sig/client.rbs', line 243
def update_service_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1047 1048 1049 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1047 def waiter_names [] end |