Class: Aws::SSMQuickSetup::Types::GetServiceSettingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSMQuickSetup::Types::GetServiceSettingsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssmquicksetup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#service_settings ⇒ Types::ServiceSettings
Returns details about the settings for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
Instance Attribute Details
#service_settings ⇒ Types::ServiceSettings
Returns details about the settings for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
1199 1200 1201 1202 1203 |
# File 'lib/aws-sdk-ssmquicksetup/types.rb', line 1199 class GetServiceSettingsOutput < Struct.new( :service_settings) SENSITIVE = [] include Aws::Structure end |