Class: Aws::SSMQuickSetup::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMQuickSetup::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmquicksetup/client.rb
Overview
An API client for SSMQuickSetup. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSMQuickSetup::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource.
-
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
-
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
-
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
-
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
-
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1054 1055 1056 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1054 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1057 1058 1059 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1057 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1027 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMQuickSetup') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmquicksetup' context[:gem_version] = '1.30.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource. This object is a collection of desired state configurations for multiple configuration definitions and summaries describing the deployments of those definitions.
528 529 530 531 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 528 def create_configuration_manager(params = {}, = {}) req = build_request(:create_configuration_manager, params) req.send_request() end |
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
550 551 552 553 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 550 def delete_configuration_manager(params = {}, = {}) req = build_request(:delete_configuration_manager, params) req.send_request() end |
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
605 606 607 608 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 605 def get_configuration(params = {}, = {}) req = build_request(:get_configuration, params) req.send_request() end |
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
661 662 663 664 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 661 def get_configuration_manager(params = {}, = {}) req = build_request(:get_configuration_manager, params) req.send_request() end |
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
681 682 683 684 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 681 def get_service_settings(params = {}, = {}) req = build_request(:get_service_settings, params) req.send_request() end |
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
743 744 745 746 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 743 def list_configuration_managers(params = {}, = {}) req = build_request(:list_configuration_managers, params) req.send_request() end |
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
815 816 817 818 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 815 def list_configurations(params = {}, = {}) req = build_request(:list_configurations, params) req.send_request() end |
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
836 837 838 839 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 836 def list_quick_setup_types(params = {}, = {}) req = build_request(:list_quick_setup_types, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
866 867 868 869 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 866 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
894 895 896 897 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 894 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
920 921 922 923 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 920 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
966 967 968 969 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 966 def update_configuration_definition(params = {}, = {}) req = build_request(:update_configuration_definition, params) req.send_request() end |
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
996 997 998 999 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 996 def update_configuration_manager(params = {}, = {}) req = build_request(:update_configuration_manager, params) req.send_request() end |
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
1018 1019 1020 1021 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1018 def update_service_settings(params = {}, = {}) req = build_request(:update_service_settings, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1047 1048 1049 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1047 def waiter_names [] end |