Class: Aws::SSMQuickSetup::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-ssmquicksetup/client.rb

Overview

An API client for SSMQuickSetup. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::SSMQuickSetup::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::SSMQuickSetup::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::SSMQuickSetup::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



473
474
475
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 473

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1056
1057
1058
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1056

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1059
1060
1061
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1059

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1029

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::SSMQuickSetup')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-ssmquicksetup'
  context[:gem_version] = '1.29.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput

Creates a Quick Setup configuration manager resource. This object is a collection of desired state configurations for multiple configuration definitions and summaries describing the deployments of those definitions.

Examples:

Request syntax with placeholder values


resp = client.create_configuration_manager({
  configuration_definitions: [ # required
    {
      local_deployment_administration_role_arn: "IAMRoleArn",
      local_deployment_execution_role_name: "ConfigurationDefinitionInputLocalDeploymentExecutionRoleNameString",
      parameters: { # required
        "ConfigurationParametersMapKeyString" => "ConfigurationParametersMapValueString",
      },
      type: "ConfigurationDefinitionInputTypeString", # required
      type_version: "ConfigurationDefinitionInputTypeVersionString",
    },
  ],
  description: "CreateConfigurationManagerInputDescriptionString",
  name: "CreateConfigurationManagerInputNameString",
  tags: {
    "TagsMapKeyString" => "TagsMapValueString",
  },
})

Response structure


resp.manager_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :configuration_definitions (required, Array<Types::ConfigurationDefinitionInput>)

    The definition of the Quick Setup configuration that the configuration manager deploys.

  • :description (String)

    A description of the configuration manager.

  • :name (String)

    A name for the configuration manager.

  • :tags (Hash<String,String>)

    Key-value pairs of metadata to assign to the configuration manager.

Returns:

See Also:



530
531
532
533
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 530

def create_configuration_manager(params = {}, options = {})
  req = build_request(:create_configuration_manager, params)
  req.send_request(options)
end

#delete_configuration_manager(params = {}) ⇒ Struct

Deletes a configuration manager.

Examples:

Request syntax with placeholder values


resp = client.delete_configuration_manager({
  manager_arn: "DeleteConfigurationManagerInputManagerArnString", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :manager_arn (required, String)

    The ID of the configuration manager.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



552
553
554
555
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 552

def delete_configuration_manager(params = {}, options = {})
  req = build_request(:delete_configuration_manager, params)
  req.send_request(options)
end

#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput

Returns details about the specified configuration.

Examples:

Request syntax with placeholder values


resp = client.get_configuration({
  configuration_id: "GetConfigurationInputConfigurationIdString", # required
})

Response structure


resp. #=> String
resp.configuration_definition_id #=> String
resp.created_at #=> Time
resp.id #=> String
resp.last_modified_at #=> Time
resp.manager_arn #=> String
resp.parameters #=> Hash
resp.parameters["ConfigurationParametersMapKeyString"] #=> String
resp.region #=> String
resp.status_summaries #=> Array
resp.status_summaries[0].last_updated_at #=> Time
resp.status_summaries[0].status #=> String, one of "INITIALIZING", "DEPLOYING", "SUCCEEDED", "DELETING", "STOPPING", "FAILED", "STOPPED", "DELETE_FAILED", "STOP_FAILED", "NONE"
resp.status_summaries[0].status_details #=> Hash
resp.status_summaries[0].status_details["String"] #=> String
resp.status_summaries[0].status_message #=> String
resp.status_summaries[0].status_type #=> String, one of "Deployment", "AsyncExecutions"
resp.type #=> String
resp.type_version #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :configuration_id (required, String)

    A service generated identifier for the configuration.

Returns:

See Also:



607
608
609
610
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 607

def get_configuration(params = {}, options = {})
  req = build_request(:get_configuration, params)
  req.send_request(options)
end

#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput

Returns a configuration manager.

Examples:

Request syntax with placeholder values


resp = client.get_configuration_manager({
  manager_arn: "GetConfigurationManagerInputManagerArnString", # required
})

Response structure


resp.configuration_definitions #=> Array
resp.configuration_definitions[0].id #=> String
resp.configuration_definitions[0].local_deployment_administration_role_arn #=> String
resp.configuration_definitions[0].local_deployment_execution_role_name #=> String
resp.configuration_definitions[0].parameters #=> Hash
resp.configuration_definitions[0].parameters["ConfigurationParametersMapKeyString"] #=> String
resp.configuration_definitions[0].type #=> String
resp.configuration_definitions[0].type_version #=> String
resp.created_at #=> Time
resp.description #=> String
resp.last_modified_at #=> Time
resp.manager_arn #=> String
resp.name #=> String
resp.status_summaries #=> Array
resp.status_summaries[0].last_updated_at #=> Time
resp.status_summaries[0].status #=> String, one of "INITIALIZING", "DEPLOYING", "SUCCEEDED", "DELETING", "STOPPING", "FAILED", "STOPPED", "DELETE_FAILED", "STOP_FAILED", "NONE"
resp.status_summaries[0].status_details #=> Hash
resp.status_summaries[0].status_details["String"] #=> String
resp.status_summaries[0].status_message #=> String
resp.status_summaries[0].status_type #=> String, one of "Deployment", "AsyncExecutions"
resp.tags #=> Hash
resp.tags["TagsMapKeyString"] #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :manager_arn (required, String)

    The ARN of the configuration manager.

Returns:

See Also:



663
664
665
666
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 663

def get_configuration_manager(params = {}, options = {})
  req = build_request(:get_configuration_manager, params)
  req.send_request(options)
end

#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput

Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.

Examples:

Response structure


resp.service_settings.explorer_enabling_role_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

See Also:



683
684
685
686
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 683

def get_service_settings(params = {}, options = {})
  req = build_request(:get_service_settings, params)
  req.send_request(options)
end

#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput

Returns Quick Setup configuration managers.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_configuration_managers({
  filters: [
    {
      key: "FilterKeyString", # required
      values: ["FilterValuesMemberString"], # required
    },
  ],
  max_items: 1,
  starting_token: "ListConfigurationManagersInputStartingTokenString",
})

Response structure


resp.configuration_managers_list #=> Array
resp.configuration_managers_list[0].configuration_definition_summaries #=> Array
resp.configuration_managers_list[0].configuration_definition_summaries[0].first_class_parameters #=> Hash
resp.configuration_managers_list[0].configuration_definition_summaries[0].first_class_parameters["ConfigurationParametersMapKeyString"] #=> String
resp.configuration_managers_list[0].configuration_definition_summaries[0].id #=> String
resp.configuration_managers_list[0].configuration_definition_summaries[0].type #=> String
resp.configuration_managers_list[0].configuration_definition_summaries[0].type_version #=> String
resp.configuration_managers_list[0].description #=> String
resp.configuration_managers_list[0].manager_arn #=> String
resp.configuration_managers_list[0].name #=> String
resp.configuration_managers_list[0].status_summaries #=> Array
resp.configuration_managers_list[0].status_summaries[0].last_updated_at #=> Time
resp.configuration_managers_list[0].status_summaries[0].status #=> String, one of "INITIALIZING", "DEPLOYING", "SUCCEEDED", "DELETING", "STOPPING", "FAILED", "STOPPED", "DELETE_FAILED", "STOP_FAILED", "NONE"
resp.configuration_managers_list[0].status_summaries[0].status_details #=> Hash
resp.configuration_managers_list[0].status_summaries[0].status_details["String"] #=> String
resp.configuration_managers_list[0].status_summaries[0].status_message #=> String
resp.configuration_managers_list[0].status_summaries[0].status_type #=> String, one of "Deployment", "AsyncExecutions"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :filters (Array<Types::Filter>)

    Filters the results returned by the request.

  • :max_items (Integer)

    Specifies the maximum number of configuration managers that are returned by the request.

  • :starting_token (String)

    The token to use when requesting a specific set of items from a list.

Returns:

See Also:



745
746
747
748
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 745

def list_configuration_managers(params = {}, options = {})
  req = build_request(:list_configuration_managers, params)
  req.send_request(options)
end

#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput

Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_configurations({
  configuration_definition_id: "ListConfigurationsInputConfigurationDefinitionIdString",
  filters: [
    {
      key: "FilterKeyString", # required
      values: ["FilterValuesMemberString"], # required
    },
  ],
  manager_arn: "ListConfigurationsInputManagerArnString",
  max_items: 1,
  starting_token: "ListConfigurationsInputStartingTokenString",
})

Response structure


resp.configurations_list #=> Array
resp.configurations_list[0]. #=> String
resp.configurations_list[0].configuration_definition_id #=> String
resp.configurations_list[0].created_at #=> Time
resp.configurations_list[0].first_class_parameters #=> Hash
resp.configurations_list[0].first_class_parameters["ConfigurationParametersMapKeyString"] #=> String
resp.configurations_list[0].id #=> String
resp.configurations_list[0].manager_arn #=> String
resp.configurations_list[0].region #=> String
resp.configurations_list[0].status_summaries #=> Array
resp.configurations_list[0].status_summaries[0].last_updated_at #=> Time
resp.configurations_list[0].status_summaries[0].status #=> String, one of "INITIALIZING", "DEPLOYING", "SUCCEEDED", "DELETING", "STOPPING", "FAILED", "STOPPED", "DELETE_FAILED", "STOP_FAILED", "NONE"
resp.configurations_list[0].status_summaries[0].status_details #=> Hash
resp.configurations_list[0].status_summaries[0].status_details["String"] #=> String
resp.configurations_list[0].status_summaries[0].status_message #=> String
resp.configurations_list[0].status_summaries[0].status_type #=> String, one of "Deployment", "AsyncExecutions"
resp.configurations_list[0].type #=> String
resp.configurations_list[0].type_version #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :configuration_definition_id (String)

    The ID of the configuration definition.

  • :filters (Array<Types::Filter>)

    Filters the results returned by the request.

  • :manager_arn (String)

    The ARN of the configuration manager.

  • :max_items (Integer)

    Specifies the maximum number of configurations that are returned by the request.

  • :starting_token (String)

    The token to use when requesting a specific set of items from a list.

Returns:

See Also:



817
818
819
820
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 817

def list_configurations(params = {}, options = {})
  req = build_request(:list_configurations, params)
  req.send_request(options)
end

#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput

Returns the available Quick Setup types.

Examples:

Response structure


resp.quick_setup_type_list #=> Array
resp.quick_setup_type_list[0].latest_version #=> String
resp.quick_setup_type_list[0].type #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Returns:

See Also:



838
839
840
841
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 838

def list_quick_setup_types(params = {}, options = {})
  req = build_request(:list_quick_setup_types, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

Returns tags assigned to the resource.

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "String", # required
})

Response structure


resp.tags #=> Array
resp.tags[0].key #=> String
resp.tags[0].value #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource the tag is assigned to.

Returns:

See Also:



868
869
870
871
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 868

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Assigns key-value pairs of metadata to Amazon Web Services resources.

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "String", # required
  tags: { # required
    "TagsMapKeyString" => "TagsMapValueString",
  },
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource to tag.

  • :tags (required, Hash<String,String>)

    Key-value pairs of metadata to assign to the resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



896
897
898
899
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 896

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes tags from the specified resource.

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "String", # required
  tag_keys: ["String"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource to remove tags from.

  • :tag_keys (required, Array<String>)

    The keys of the tags to remove from the resource.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



922
923
924
925
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 922

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_configuration_definition(params = {}) ⇒ Struct

Updates a Quick Setup configuration definition.

Examples:

Request syntax with placeholder values


resp = client.update_configuration_definition({
  id: "UpdateConfigurationDefinitionInputIdString", # required
  local_deployment_administration_role_arn: "IAMRoleArn",
  local_deployment_execution_role_name: "UpdateConfigurationDefinitionInputLocalDeploymentExecutionRoleNameString",
  manager_arn: "UpdateConfigurationDefinitionInputManagerArnString", # required
  parameters: {
    "ConfigurationParametersMapKeyString" => "ConfigurationParametersMapValueString",
  },
  type_version: "UpdateConfigurationDefinitionInputTypeVersionString",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :id (required, String)

    The ID of the configuration definition you want to update.

  • :local_deployment_administration_role_arn (String)

    The ARN of the IAM role used to administrate local configuration deployments.

  • :local_deployment_execution_role_name (String)

    The name of the IAM role used to deploy local configurations.

  • :manager_arn (required, String)

    The ARN of the configuration manager associated with the definition to update.

  • :parameters (Hash<String,String>)

    The parameters for the configuration definition type.

  • :type_version (String)

    The version of the Quick Setup type to use.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



968
969
970
971
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 968

def update_configuration_definition(params = {}, options = {})
  req = build_request(:update_configuration_definition, params)
  req.send_request(options)
end

#update_configuration_manager(params = {}) ⇒ Struct

Updates a Quick Setup configuration manager.

Examples:

Request syntax with placeholder values


resp = client.update_configuration_manager({
  description: "UpdateConfigurationManagerInputDescriptionString",
  manager_arn: "UpdateConfigurationManagerInputManagerArnString", # required
  name: "UpdateConfigurationManagerInputNameString",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :description (String)

    A description of the configuration manager.

  • :manager_arn (required, String)

    The ARN of the configuration manager.

  • :name (String)

    A name for the configuration manager.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



998
999
1000
1001
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 998

def update_configuration_manager(params = {}, options = {})
  req = build_request(:update_configuration_manager, params)
  req.send_request(options)
end

#update_service_settings(params = {}) ⇒ Struct

Updates settings configured for Quick Setup.

Examples:

Request syntax with placeholder values


resp = client.update_service_settings({
  explorer_enabling_role_arn: "IAMRoleArn",
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :explorer_enabling_role_arn (String)

    The IAM role used to enable Explorer.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1020
1021
1022
1023
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1020

def update_service_settings(params = {}, options = {})
  req = build_request(:update_service_settings, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1049
1050
1051
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1049

def waiter_names
  []
end