Class: Aws::SSMQuickSetup::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSMQuickSetup::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssmquicksetup/client.rb
Overview
An API client for SSMQuickSetup. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSMQuickSetup::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource.
-
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
-
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
-
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
-
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
-
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
-
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
-
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
-
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1056 1057 1058 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1056 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1059 1060 1061 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1059 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1029 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSMQuickSetup') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssmquicksetup' context[:gem_version] = '1.29.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_manager(params = {}) ⇒ Types::CreateConfigurationManagerOutput
Creates a Quick Setup configuration manager resource. This object is a collection of desired state configurations for multiple configuration definitions and summaries describing the deployments of those definitions.
530 531 532 533 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 530 def create_configuration_manager(params = {}, = {}) req = build_request(:create_configuration_manager, params) req.send_request() end |
#delete_configuration_manager(params = {}) ⇒ Struct
Deletes a configuration manager.
552 553 554 555 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 552 def delete_configuration_manager(params = {}, = {}) req = build_request(:delete_configuration_manager, params) req.send_request() end |
#get_configuration(params = {}) ⇒ Types::GetConfigurationOutput
Returns details about the specified configuration.
607 608 609 610 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 607 def get_configuration(params = {}, = {}) req = build_request(:get_configuration, params) req.send_request() end |
#get_configuration_manager(params = {}) ⇒ Types::GetConfigurationManagerOutput
Returns a configuration manager.
663 664 665 666 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 663 def get_configuration_manager(params = {}, = {}) req = build_request(:get_configuration_manager, params) req.send_request() end |
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsOutput
Returns settings configured for Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
683 684 685 686 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 683 def get_service_settings(params = {}, = {}) req = build_request(:get_service_settings, params) req.send_request() end |
#list_configuration_managers(params = {}) ⇒ Types::ListConfigurationManagersOutput
Returns Quick Setup configuration managers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
745 746 747 748 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 745 def list_configuration_managers(params = {}, = {}) req = build_request(:list_configuration_managers, params) req.send_request() end |
#list_configurations(params = {}) ⇒ Types::ListConfigurationsOutput
Returns configurations deployed by Quick Setup in the requesting Amazon Web Services account and Amazon Web Services Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
817 818 819 820 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 817 def list_configurations(params = {}, = {}) req = build_request(:list_configurations, params) req.send_request() end |
#list_quick_setup_types(params = {}) ⇒ Types::ListQuickSetupTypesOutput
Returns the available Quick Setup types.
838 839 840 841 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 838 def list_quick_setup_types(params = {}, = {}) req = build_request(:list_quick_setup_types, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags assigned to the resource.
868 869 870 871 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 868 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns key-value pairs of metadata to Amazon Web Services resources.
896 897 898 899 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 896 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
922 923 924 925 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 922 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_configuration_definition(params = {}) ⇒ Struct
Updates a Quick Setup configuration definition.
968 969 970 971 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 968 def update_configuration_definition(params = {}, = {}) req = build_request(:update_configuration_definition, params) req.send_request() end |
#update_configuration_manager(params = {}) ⇒ Struct
Updates a Quick Setup configuration manager.
998 999 1000 1001 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 998 def update_configuration_manager(params = {}, = {}) req = build_request(:update_configuration_manager, params) req.send_request() end |
#update_service_settings(params = {}) ⇒ Struct
Updates settings configured for Quick Setup.
1020 1021 1022 1023 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1020 def update_service_settings(params = {}, = {}) req = build_request(:update_service_settings, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1049 1050 1051 |
# File 'lib/aws-sdk-ssmquicksetup/client.rb', line 1049 def waiter_names [] end |